#
# spec file for package libvpd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion -2_2-3
# 15.2 is no longer updated but is supported migration target
# versions before 15.2 cannot have a package that obsoletes libvpd2
# to be able to migrate to 15.2 which has lsvpd that requires libvpd2
# let libvpd2 provide the udev rules instead
%define basepackage ( ! 0%{?sle_version} || 0%{?sle_version} >= 150200 )

Name:           libvpd
Version:        2.2.10
Release:        1.3
Summary:        VPD Database access library for lsvpd
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/power-ras/libvpd
Source:         https://github.com/power-ras/libvpd/archive/v%{version}.tar.gz#/%{name}2-%{version}.tar.gz
Source1:        baselibs.conf
Patch1:         libvpd2.makefile.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(zlib)

%description
The libvpd package contains classes that are used to access a Vital
Product Data (VPD) database created by vpdupdate in the lsvpd package.

%package -n %{name}%{soversion}
Summary:        VPD Database access library for lsvpd
Group:          System/Libraries
%if %basepackage
Requires:       %{name}-base
%else
Requires:       libvpd2
%endif

%description -n %{name}%{soversion}
The libvpd package contains classes that are used to access a Vital
Product Data (VPD) database created by vpdupdate in the lsvpd package.

%package base
Summary:        Udev rules for VPD Database access library
Group:          System/Libraries
Obsoletes:      libvpd2 < 2.2.9

%description base
Udev rules for libvpd library used to access a vpd database created by
vpdupdate in the lsvpd package.

%package devel
Summary:        VPD Database access library for lsvpd
Group:          Development/Languages/C and C++
Requires:       %{name}%{soversion} = %{version}-%{release}
Requires:       pkgconfig(sqlite3)
Obsoletes:      libvpd2-devel < 2.2.9

%description devel
The libvpd-devel package contains development libraries and header
files that are used to access a vpd database created by vpdupdate in
the lsvpd package.

%prep
%autosetup -p1

%build
%if 0%{?sle_version} && 0%{?sle_version} < 150000
CFLAGS="%optflags -std=gnu99"
export CFLAGS
%endif
autoreconf -fiv
%configure \
  --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%if ! %basepackage
rm %{buildroot}%{_udevrulesdir}/90-vpdupdate.rules
rmdir -p --ignore-fail-on-non-empty %{buildroot}%{_udevrulesdir}
%endif

%post -n %{name}%{soversion} -p /sbin/ldconfig
%postun -n %{name}%{soversion} -p /sbin/ldconfig

%files -n %{name}%{soversion}
%{_libdir}/*.so.*

%if %basepackage
%files base
%{_udevrulesdir}/90-vpdupdate.rules
%endif

%files devel
%license COPYING
%doc README
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%changelog
* Tue Sep 17 2024 Michal Suchanek <msuchanek@suse.com>
- Version 2.2.10 (jsc#PED-9911).
  * Fix displaying duplicate VPD details
* Thu Apr 21 2022 Michal Suchanek <msuchanek@suse.com>
- Fix inverted basepackage condition
* Wed Apr 20 2022 Michal Suchanek <msuchanek@suse.com>
- Allow for migration to 15.2 from earlier releases
- Fix build on SLE12
* Tue Apr 19 2022 Michal Suchanek <msuchanek@suse.com>
- Split udev rules into a separate package
- Obsolete libvpd2 by udev rules
- Obsolete 32bit devel package
* Thu Apr 14 2022 Michal Suchanek <msuchanek@suse.com>
- Update to version 2.2.9
  - VpdDbEnv: Add locking fo the database file (bsc#1187665 ltc#194646).
  - Update libtool version info
  - Drop upstreamed patch
  - 0001-Remove-dynamic-exception-specification.patch
- Package name change from libvpd2 to libvpd
* Tue Jun  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add GCC 11 compatibility fix:
  * 0001-Remove-dynamic-exception-specification.patch
* Mon Nov 16 2020 Michal Suchanek <msuchanek@suse.com>
- Update to version 2.2.8 (jsc#SLE-12939).
  - Reduce system load from vpdupdate udev rule
  - VpdDbEnv: Make the sqlite operations asynchronous
    This will improve `vpdupdate` performance quite a bit.
  - Remove upstreamed patches
  - udev-rules-don-t-touch-run.vpdupdate-for-ignored-dev.patch
  - udev-rules-more-software-devices-to-ignore.patch
  - udev-rules-don-t-generate-multiple-vpdupdate-events-.patch
  - Update project and source URL
* Wed Feb 19 2020 Josef Möllers <josef.moellers@suse.com>
- Amended existing patch
  udev-rules-don-t-generate-multiple-vpdupdate-events-.patch
  with a single initial rule to avoid anything not /device/.
  [bsc#1164300,
  udev-rules-don-t-generate-multiple-vpdupdate-events-.patch]
* Tue Jan 28 2020 Martin Wilck <mwilck@suse.com>
- Avoid boot stalls due to excessive udev rule execution
  (bsc#1154837)
  * added udev-rules-don-t-touch-run.vpdupdate-for-ignored-dev.patch
  * added udev-rules-more-software-devices-to-ignore.patch
  * added udev-rules-don-t-generate-multiple-vpdupdate-events-.patch
* Wed Jan 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to pkgconfig dependencies
- Use %%license macro
* Wed Jun 20 2018 jloeser@suse.com
- version update to 2.2.6 (fate#324940, fate#326425)
  - Changes run.vpdupdate creation path from /var/lib/lsvpd to /run
- removed patches:
  * 0001-Modify-char-array-initialization-style.patch
  * 0002-Null-check-before-passing-pointer-to-strlen-call.patch
  * 0003-Typo-correction-in-README-file.patch
  * 0004-libvpd-Validate-memory-allocation.patch
  * 0005-libvpd-Corrects-data-type-of-variables.patch
  * 0006-Changes-run.vpdupdate-creation-path-from-var-lib-lsv.patch
  * libvpd.async.patch
- modified patches:
  * libvpd2.makefile.patch
* Fri Jun  1 2018 normand@linux.vnet.ibm.com
- Add 6 patches from upstream:
  0001-Modify-char-array-initialization-style.patch
    this one differ from upstream as do not remove QUERY_BUF_LENGTH
    still used in not upstream libvpd.async.patch
  0002-Null-check-before-passing-pointer-to-strlen-call.patch
  0003-Typo-correction-in-README-file.patch
  0004-libvpd-Validate-memory-allocation.patch
  0005-libvpd-Corrects-data-type-of-variables.patch
  0006-Changes-run.vpdupdate-creation-path-from-var-lib-lsv.patch
    last one to avoid reported error systemd-udevd error:
    'touch /var/lib/lsvpd/run.vpdupdate' failed with exit code 1
* Tue Nov 24 2015 p.drouand@gmail.com
- Update to version 2.2.5 (fate#322221)
  * Fixed security issues like buffer overflow, memory allocation
    validation
  * Replaced popen with secured version
  * Improved error handling
- Update libvpd.async.patch
* Wed Aug  5 2015 mpluskal@suse.com
- Move autoreconf to build phase (avoids issues with quilt)
* Wed Sep  3 2014 jloeser@suse.com
- version update to 2.2.4 (BNC#894858)
- modified patches:
  * libvpd2.makefile.patch
* Tue May 13 2014 tchvatal@suse.com
- Version bump to 2.2.3:
  * Restrict vpdupdate triggers to device change events
- Cleanup with spec-cleaner
- Add libtool and autoconf as requirements and reconfigure the
  autofoo*
- Add download url proper for the tarball.
- Remove no longer needed patch libvpd2-gcc47.patch
* Fri Jan 17 2014 jloeser@suse.com
- version update to 2.2.2 (FATE#315460)
  minor bugfixes
  add udev rule for vpdupdate
  no upstream changelog provided
- libvpd2.makefile.patch: fix udev rules directory
- add udev and automake to BuildRequires for correct udev rules.d
  directory
* Thu Dec  6 2012 dvaleev@suse.com
- update to 2.2.0
  No upstream changelog provided
- don't run autoreconf
- remove libtool from BuildRequires
* Fri Jun  1 2012 jloeser@suse.com
- clean up spec file
* Wed Mar 21 2012 dimstar@opensuse.org
- Add libvpd2-gcc47.patch: Fix build with gcc 4.7.
* Tue Dec 20 2011 dmueller@suse.de
- spec file cleanups
* Thu Nov  3 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel build
- Remove redundant tags/sections (cf. specfile guidelines)
* Tue Nov  1 2011 dvaleev@suse.com
- update to 2.1.3
  - Rebuild rpms for ppc 32-bit.
  - add pkg-config to BuildRequires to avoid rpmlint warings
  - drop libvpd-pkg.patch and libvpd.return-value.patch
* Mon Apr 18 2011 ro@suse.de
- update baselibs.conf
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Mon Dec  8 2008 olh@suse.de
- set 'PRAGMA synchronous = OFF;' to avoid fsync for each string
  (bnc#449648)
* Fri Nov 21 2008 sassmann@suse.de
- rename package to libvpd2 because it now contains libs for
  both C and C++ (bnc#444531)
- cleanup broken SONAME (bnc#444531)
* Wed Jun 25 2008 olh@suse.de
- add baselibs.conf
- rename to libvpd_cxx2
- update to libvpd-2.0.3 (fate#304148)
  no changelog in package
* Wed Oct 24 2007 sassmann@suse.de
- fix includes to build on beta-i386, beta-x86_64
* Wed Oct 17 2007 sassmann@suse.de
- initial release of libvpd_cxx (version 1.3.5)
